@@ -1,24 +1,9 @@
 /*
-  Copyright (C) 2008 by Eike Hein <hein@kde.org>
+  SPDX-FileCopyrightText: 2008 Eike Hein <hein@kde.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see https://www.gnu.org/licenses/.
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-
 #include "skinlistdelegate.h"
 #include "appearancesettings.h"
 
@@ -28,13 +13,12 @@
 #include <QModelIndex>
 #include <QPainter>
 
-
 #define MARGIN 3
 #define ICON 32
 #define KNS_ICON_SIZE (ICON / 2)
 
-
-SkinListDelegate::SkinListDelegate(QObject* parent) : QAbstractItemDelegate(parent)
+SkinListDelegate::SkinListDelegate(QObject *parent)
+    : QAbstractItemDelegate(parent)
 {
 }
 
@@ -42,7 +26,7 @@ SkinListDelegate::~SkinListDelegate()
 {
 }
 
-void SkinListDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex &index) const
+void SkinListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     painter->save();
 
@@ -55,21 +39,20 @@ void SkinListDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opti
     painter->restore();
 }
 
-void SkinListDelegate::paintBackground(QPainter* painter, const QStyleOptionViewItem& option) const
+void SkinListDelegate::paintBackground(QPainter *painter, const QStyleOptionViewItem &option) const
 {
     QStyleOptionViewItem opt = option;
-    QStyle* style = opt.widget ? opt.widget->style() : QApplication::style();
+    QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
     style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
 }
 
-void SkinListDelegate::paintIcon(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex &index) const
+void SkinListDelegate::paintIcon(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QVariant value;
 
     value = index.data(AppearanceSettings::SkinIcon);
 
-    if (value.isValid() && value.type() == QVariant::Icon)
-    {
+    if (value.isValid() && value.type() == QVariant::Icon) {
         int x = option.rect.x() + MARGIN;
         int y = option.rect.y() + (option.rect.height() / 2) - (ICON / 2);
 
@@ -80,7 +63,7 @@ void SkinListDelegate::paintIcon(QPainter* painter, const QStyleOptionViewItem&
     }
 }
 
-void SkinListDelegate::paintText(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex &index) const
+void SkinListDelegate::paintText(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QFont font = option.font;
     int initialY = option.rect.y();
@@ -96,8 +79,7 @@ void SkinListDelegate::paintText(QPainter* painter, const QStyleOptionViewItem&
 
     value = index.data(AppearanceSettings::SkinName);
 
-    if (value.isValid())
-    {
+    if (value.isValid()) {
         font.setBold(true);
         painter->setFont(font);
         QFontMetrics fontMetrics(font);
@@ -105,8 +87,7 @@ void SkinListDelegate::paintText(QPainter* painter, const QStyleOptionViewItem&
         QRect textRect = fontMetrics.boundingRect(value.toString());
         textWidth = textRect.width();
 
-        if (option.direction == Qt::RightToLeft)
-        {
+        if (option.direction == Qt::RightToLeft) {
             if (width < textWidth)
                 x = option.rect.x() + MARGIN;
             else
@@ -119,8 +100,7 @@ void SkinListDelegate::paintText(QPainter* painter, const QStyleOptionViewItem&
 
         value = index.data(AppearanceSettings::SkinInstalledWithKns);
 
-        if (value.isValid() && value.toBool())
-        {
+        if (value.isValid() && value.toBool()) {
             QIcon ghnsIcon(QStringLiteral("get-hot-new-stuff"));
             int knsIconX = x;
             int iconSize = qMin(textRect.height(), KNS_ICON_SIZE);
@@ -141,8 +121,7 @@ void SkinListDelegate::paintText(QPainter* painter, const QStyleOptionViewItem&
 
     value = index.data(AppearanceSettings::SkinAuthor);
 
-    if (value.isValid())
-    {
+    if (value.isValid()) {
         QString skinAuthor = xi18nc("@item:intext", "by %1", value.toString());
 
         font.setBold(false);
@@ -151,8 +130,7 @@ void SkinListDelegate::paintText(QPainter* painter, const QStyleOptionViewItem&
 
         QRect textRect = fontMetrics.boundingRect(skinAuthor);
 
-        if (option.direction == Qt::RightToLeft)
-        {
+        if (option.direction == Qt::RightToLeft) {
             if (width < textRect.width())
                 x = option.rect.x() + MARGIN;
             else
@@ -165,7 +143,7 @@ void SkinListDelegate::paintText(QPainter* painter, const QStyleOptionViewItem&
     }
 }
 
-QSize SkinListDelegate::sizeHint(const QStyleOptionViewItem&option, const QModelIndex& index) const
+QSize SkinListDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QFont font = option.font;
     QRect name, author;
@@ -175,8 +153,7 @@ QSize SkinListDelegate::sizeHint(const QStyleOptionViewItem&option, const QModel
 
     value = index.data(AppearanceSettings::SkinName);
 
-    if (value.isValid())
-    {
+    if (value.isValid()) {
         font.setBold(true);
         QFontMetrics fontMetrics(font);
         name = fontMetrics.boundingRect(value.toString());
@@ -184,8 +161,7 @@ QSize SkinListDelegate::sizeHint(const QStyleOptionViewItem&option, const QModel
 
     value = index.data(Qt::UserRole + 1);
 
-    if (value.isValid())
-    {
+    if (value.isValid()) {
         QString skinAuthor = xi18nc("@item:intext", "by %1", value.toString());
 
         font.setBold(false);
@@ -196,7 +172,7 @@ QSize SkinListDelegate::sizeHint(const QStyleOptionViewItem&option, const QModel
     width = qMax(name.width(), author.width());
     QRect textRect(0, 0, width, name.height() + author.height());
 
-    width = ICON + (3 * MARGIN) + textRect.width() + MARGIN;;
+    width = ICON + (3 * MARGIN) + textRect.width() + MARGIN;
     height = qMax(ICON + (2 * MARGIN), textRect.height() + (2 * MARGIN));
 
     return QSize(width, height);
